@@ -1,6 +1,8 @@
-from magplan.models import Issue
 import os
-# from django.contrib.sites.models import Site
+
+from django.contrib.sites.models import Site
+
+from magplan.models import Issue
 
 
 def inject_last_issues(request):
@@ -11,10 +13,14 @@ def inject_last_issues(request):
 
 
 def inject_app_url(request):
-    # def current_site_failback():
-    #     current_site = Site.objects.get_current()
-    #     return current_site.domain
-
     return {
         'APP_URL': os.environ.get('APP_URL', None),
-    }
\ No newline at end of file
+    }
+
+
+def inject_sites(request):
+    current_site: Site = Site.objects.get_current(request=request)
+    return {
+        'current_site': current_site,
+        'sites': Site.objects.exclude(id=current_site.id),
+    }
